@@ -1,13 +1,13 @@
-# Copyrights 2001-2012 by [Mark Overmeer].
+# Copyrights 2001-2013 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 use strict;
 use warnings;
 
 package Mail::Message::Field::Addresses;
 use vars '$VERSION';
-$VERSION = '2.104';
+$VERSION = '2.108';
 
 use base 'Mail::Message::Field::Structured';
 
@@ -156,7 +156,7 @@ sub parse($)
             $angle =~ s/^\@.*?\://;
 
             ($email, $angle) = $self->consumeAddress($angle
-                , phrase => $phrase, comment => $comment);
+              , phrase => $phrase, comment => $comment);
         }
 
         $self->addAddress($email, group => $group) if defined $email;
@@ -197,8 +197,8 @@ sub consumeAddress($@)
     return (undef, $string) unless defined $domain;
 
     # loccomment and domcomment ignored
-    my $email   = Mail::Message::Field::Address->new
-     ( username => $local, domain => $domain, @options);
+    my $email   = Mail::Message::Field::Address
+        ->new(username => $local, domain => $domain, @options);
 
     ($email, $shorter);
 }
