@@ -1,14 +1,14 @@
-# Copyrights 2001-2012 by [Mark Overmeer].
+# Copyrights 2001-2013 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 
 use strict;
 use warnings;
 
 package Mail::Message::Replace::MailInternet;
 use vars '$VERSION';
-$VERSION = '2.106';
+$VERSION = '2.108';
 
 use base 'Mail::Message';
 
@@ -153,7 +153,7 @@ sub reply(@)
     my $home       = $ENV{HOME} || File::Spec->curdir;
     my $headtemp   = File::Spec->catfile($home, '.mailhdr');
 
-    if(open HEAD, '<', $headtemp)
+    if(open HEAD, '<:raw', $headtemp)
     {    my $parser = Mail::Box::Parser::Perl->new
            ( filename  => $headtemp
            , file      => \*HEAD
