@@ -1,13 +1,13 @@
-# Copyrights 2001-2012 by [Mark Overmeer].
+# Copyrights 2001-2013 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 use strict;
 use warnings;
 
 package Mail::Reporter;
 use vars '$VERSION';
-$VERSION = '2.107';
+$VERSION = '2.108';
 
 
 use Carp;
@@ -233,10 +233,6 @@ sub AUTOLOAD(@)
 #-------------------------------------------
 
 
-my $global_destruction;
-END {$global_destruction++}
-sub inGlobalDestruction() {$global_destruction}
-
 #-------------------------------------------
 
 
